## Installation
``` bash
$ pip install git+https://github.com/openai/whisper.git
$ pip install vChatGPT
```

## Execute verbal ChatGPT
``` bash
$ export OPENAI_API_KEY="16-DIGIT-YOUR_API_KEY"
$ python -m vChatGPT
```
